# POPV

Create a new anaconda environment with:
```python
conda create -n yourenv python=3.7
conda activate yourenv
conda install -c anaconda -c conda-forge cudnn==8.2.1.32 cudatoolkit==11.0.221
```
Install popv with:
`pip install popv`
